summaryrefslogtreecommitdiff
path: root/coverage/sqldata.py
diff options
context:
space:
mode:
Diffstat (limited to 'coverage/sqldata.py')
-rw-r--r--coverage/sqldata.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/coverage/sqldata.py b/coverage/sqldata.py
index 4baea331..0a2f87a5 100644
--- a/coverage/sqldata.py
+++ b/coverage/sqldata.py
@@ -22,8 +22,8 @@ import threading
import zlib
from typing import (
cast, Any, Callable, Collection, Dict, Generator, Iterable, List, Mapping, Optional,
Sequence, Set, Tuple, TypeVar, Union,
)
from coverage.debug import NoDebugging, AutoReprMixin, clipped_repr
@@ -1171,7 +1171,7 @@ class SqliteDb(AutoReprMixin):
self,
sql: str,
parameters: Iterable[Any]=(),
- ) -> Generator[sqlite3.Cursor, None, None]:
+ ) -> Iterator[sqlite3.Cursor]:
"""Context managed :meth:`python:sqlite3.Connection.execute`.
Use with a ``with`` statement to auto-close the returned cursor.
@@ -22,8 +22,8 @@ import threading
import zlib
from typing import (
- cast, Any, Callable, Collection, Dict, Generator, Iterable, List, Mapping, Optional,
- Sequence, Set, Tuple, TypeVar, Union,
+ cast, Any, Callable, Collection, Dict, Iterable, Iterator, List, Mapping,
+ Optional, Sequence, Set, Tuple, TypeVar, Union,
)
from coverage.debug import NoDebugging, AutoReprMixin, clipped_repr